# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/subscription_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.community import subscription_pb2 as eolymp_dot_community_dot_subscription__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+eolymp/community/subscription_service.proto\x12\x10\x65olymp.community\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a#eolymp/community/subscription.proto\"6\n\x16ListSubscriptionsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"W\n\x17ListSubscriptionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12-\n\x05items\x18\x02 \x03(\x0b\x32\x1e.eolymp.community.Subscription\"4\n\x19\x44\x65scribeSubscriptionInput\x12\x17\n\x0fsubscription_id\x18\x01 \x01(\t\"R\n\x1a\x44\x65scribeSubscriptionOutput\x12\x34\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1e.eolymp.community.Subscription2\x9a\x03\n\x13SubscriptionService\x12\xcd\x01\n\x14\x44\x65scribeSubscription\x12+.eolymp.community.DescribeSubscriptionInput\x1a,.eolymp.community.DescribeSubscriptionOutput\"Z\x82\xe3\n\x1f\x8a\xe3\n\x1b\x63ommunity:subscription:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\"\x12 /subscriptions/{subscription_id}\x12\xb2\x01\n\x11ListSubscriptions\x12(.eolymp.community.ListSubscriptionsInput\x1a).eolymp.community.ListSubscriptionsOutput\"H\x82\xe3\n\x1f\x8a\xe3\n\x1b\x63ommunity:subscription:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x10\x12\x0e/subscriptionsB5Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.subscription_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _SUBSCRIPTIONSERVICE.methods_by_name['DescribeSubscription']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['DescribeSubscription']._serialized_options = b'\202\343\n\037\212\343\n\033community:subscription:read\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\"\022 /subscriptions/{subscription_id}'
  _SUBSCRIPTIONSERVICE.methods_by_name['ListSubscriptions']._options = None
  _SUBSCRIPTIONSERVICE.methods_by_name['ListSubscriptions']._serialized_options = b'\202\343\n\037\212\343\n\033community:subscription:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\020\022\016/subscriptions'
  _LISTSUBSCRIPTIONSINPUT._serialized_start=201
  _LISTSUBSCRIPTIONSINPUT._serialized_end=255
  _LISTSUBSCRIPTIONSOUTPUT._serialized_start=257
  _LISTSUBSCRIPTIONSOUTPUT._serialized_end=344
  _DESCRIBESUBSCRIPTIONINPUT._serialized_start=346
  _DESCRIBESUBSCRIPTIONINPUT._serialized_end=398
  _DESCRIBESUBSCRIPTIONOUTPUT._serialized_start=400
  _DESCRIBESUBSCRIPTIONOUTPUT._serialized_end=482
  _SUBSCRIPTIONSERVICE._serialized_start=485
  _SUBSCRIPTIONSERVICE._serialized_end=895
# @@protoc_insertion_point(module_scope)
