from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.atlas import attachment_service_pb2 as _attachment_service_pb2
from eolymp.atlas import bookmark_service_pb2 as _bookmark_service_pb2
from eolymp.atlas import code_template_service_pb2 as _code_template_service_pb2
from eolymp.atlas import library_service_pb2 as _library_service_pb2
from eolymp.atlas import problem_service_pb2 as _problem_service_pb2
from eolymp.atlas import scoring_service_pb2 as _scoring_service_pb2
from eolymp.atlas import statement_service_pb2 as _statement_service_pb2
from eolymp.atlas import submission_service_pb2 as _submission_service_pb2
from eolymp.atlas import testing_service_pb2 as _testing_service_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
