# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/community/subscription.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#eolymp/community/subscription.proto\x12\x10\x65olymp.community\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa6\x05\n\x0cSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07tier_id\x18\x02 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nrenewed_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\trenews_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tpaused_at\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0epayment_method\x18\x14 \x01(\t\x12=\n\nrecurrence\x18\x1e \x01(\x0e\x32).eolymp.community.Subscription.Recurrence\x12\x10\n\x08\x63urrency\x18\x1f \x01(\t\x12\x0e\n\x06\x61mount\x18  \x01(\r\x12\x10\n\x08tax_name\x18) \x01(\t\x12\x12\n\ntax_amount\x18* \x01(\r\x12\x16\n\x0etax_percentage\x18+ \x01(\r\"=\n\nRecurrence\x12\x16\n\x12UNKNOWN_RECURRENCE\x10\x00\x12\x0b\n\x07MONTHLY\x10\x01\x12\n\n\x06YEARLY\x10\x02\"P\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\n\n\x06PAUSED\x10\x03\x12\r\n\tCANCELLED\x10\x04\x42\x35Z3github.com/eolymp/go-sdk/eolymp/community;communityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.community.subscription_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z3github.com/eolymp/go-sdk/eolymp/community;community'
  _SUBSCRIPTION._serialized_start=91
  _SUBSCRIPTION._serialized_end=769
  _SUBSCRIPTION_RECURRENCE._serialized_start=626
  _SUBSCRIPTION_RECURRENCE._serialized_end=687
  _SUBSCRIPTION_STATUS._serialized_start=689
  _SUBSCRIPTION_STATUS._serialized_end=769
# @@protoc_insertion_point(module_scope)
