# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/discussion.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/discussion/discussion.proto\x12\x11\x65olymp.discussion\x1a\x18\x65olymp/ecm/content.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe1\x02\n\nDiscussion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x03 \x01(\t\x12\x0c\n\x03url\x18\xaa\x05 \x01(\t\x12\x38\n\x05links\x18\xab\x05 \x03(\x0b\x32(.eolymp.discussion.Discussion.LinksEntry\x12\x12\n\nvote_count\x18\n \x01(\x05\x12\x13\n\x0breply_count\x18\x0b \x01(\x05\x12.\n\ncreated_at\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07subject\x18\x64 \x01(\t\x12$\n\x07message\x18\x65 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.discussion_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _DISCUSSION_LINKSENTRY._options = None
  _DISCUSSION_LINKSENTRY._serialized_options = b'8\001'
  _DISCUSSION._serialized_start=117
  _DISCUSSION._serialized_end=470
  _DISCUSSION_LINKSENTRY._serialized_start=426
  _DISCUSSION_LINKSENTRY._serialized_end=470
# @@protoc_insertion_point(module_scope)
