# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/acl/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.acl import acl_service_pb2 as eolymp_dot_acl_dot_acl__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x65olymp/acl/events.proto\x12\neolymp.acl\x1a\x1c\x65olymp/acl/acl_service.proto\"\xc6\x01\n\x16PermissionChangeRecord\x12\x38\n\x02op\x18\x01 \x01(\x0e\x32,.eolymp.acl.PermissionChangeRecord.Operation\x12\x10\n\x08space_id\x18\x02 \x01(\t\x12*\n\npermission\x18\x03 \x01(\x0b\x32\x16.eolymp.acl.Permission\"4\n\tOperation\x12\x10\n\x0cNO_OPERATION\x10\x00\x12\t\n\x05GRANT\x10\x01\x12\n\n\x06REVOKE\x10\x02\x42)Z\'github.com/eolymp/go-sdk/eolymp/acl;aclb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.acl.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\'github.com/eolymp/go-sdk/eolymp/acl;acl'
  _PERMISSIONCHANGERECORD._serialized_start=70
  _PERMISSIONCHANGERECORD._serialized_end=268
  _PERMISSIONCHANGERECORD_OPERATION._serialized_start=216
  _PERMISSIONCHANGERECORD_OPERATION._serialized_end=268
# @@protoc_insertion_point(module_scope)
