# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/discussion/forum.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x65olymp/discussion/forum.proto\x12\x11\x65olymp.discussion\x1a\x18\x65olymp/ecm/content.proto\"\xcc\x01\n\x05\x46orum\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tparent_id\x18\x02 \x01(\t\x12\x0c\n\x03url\x18\xaa\x05 \x01(\t\x12\x33\n\x05links\x18\xab\x05 \x03(\x0b\x32#.eolymp.discussion.Forum.LinksEntry\x12\r\n\x05title\x18\x64 \x01(\t\x12$\n\x07summary\x18\x65 \x01(\x0b\x32\x13.eolymp.ecm.Content\x1a,\n\nLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x37Z5github.com/eolymp/go-sdk/eolymp/discussion;discussionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.discussion.forum_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z5github.com/eolymp/go-sdk/eolymp/discussion;discussion'
  _FORUM_LINKSENTRY._options = None
  _FORUM_LINKSENTRY._serialized_options = b'8\001'
  _FORUM._serialized_start=79
  _FORUM._serialized_end=283
  _FORUM_LINKSENTRY._serialized_start=239
  _FORUM_LINKSENTRY._serialized_end=283
# @@protoc_insertion_point(module_scope)
